@@ -4,31 +4,23 @@ import csv
 import argparse
 
 
-def main(mainListFile,toRemoveListFile,outputfileName,inverse):
-    #~ parser = argparse.ArgumentParser(description="This program removes gens from a tab separated allele profile file")
-    #~ parser.add_argument('-i', nargs='?', type=str, help='main matrix file from which to remove', required=True)
-    #~ parser.add_argument('-g', nargs='?', type=str, help='list of genes to remove', required=True)
-    #~ parser.add_argument('-o', nargs='?', type=str, help='output file name', required=True)
-    #~ parser.add_argument("--inverse", help="list to remove is actually the one to keep", dest='inverse',
-    #~ action="store_true", default=False)
-    #~
-    #~ args = parser.parse_args()
-    #~ mainListFile = args.i
-    #~ toRemoveListFile = args.g
-    #~ outputfileName = args.o
-    #~ inverse = args.inverse
+def main(mainListFile, toRemoveListFile, outputfileName, inverse):
 
     if inverse:
         FilesToRemove = ['File', 'FILE', 'file']
     else:
         FilesToRemove = []
+
     with open(toRemoveListFile) as f:
+        i = 0
         for File in f:
             File = File.rstrip('\n')
             File = File.rstrip('\r')
             File = (File.split('\t'))[0]
             FilesToRemove.append(File)
-    # print FilesToRemove
+            i += 1
+
+    print('\nProvided list has {0} genes.'.format(i-1))
 
     with open(mainListFile, 'r') as tsvin, open(outputfileName + ".tsv", "w") as csvout:
         tsvin = csv.reader(tsvin, delimiter='\t')
@@ -41,6 +33,8 @@ def main(mainListFile,toRemoveListFile,outputfileName,inverse):
                 elif gene not in FilesToRemove and inverse:
                     listindextoremove.append(firstline.index(gene))
 
+            print('Removing {0} genes...'.format(len(listindextoremove)), end='')
+
             for elem in reversed(listindextoremove):
                 del firstline[elem]
             csvout.write(('\t'.join(firstline)) + "\n")
@@ -51,6 +45,9 @@ def main(mainListFile,toRemoveListFile,outputfileName,inverse):
                 del line[elem]
             csvout.write(('\t'.join(line)) + "\n")
 
+        print('done.')
+
 
 if __name__ == "__main__":
+
     main()
